@@ -1,5 +1,7 @@
 from napoleontoolbox.rebalancing import rolling
 from sklearn.metrics import mean_squared_error
+from sklearn.metrics import accuracy_score
+from sklearn.metrics import confusion_matrix
 import pandas as pd
 
 def rolling_forecasting(forecasting_model, X, y, n=252, s=63, method = 'standard', display = False, **kwargs):
@@ -18,8 +20,17 @@ def rolling_forecasting(forecasting_model, X, y, n=252, s=63, method = 'standard
         forecasting_model.fit(X_train, y_train, method)
         y_pred = forecasting_model.predict(X_test, method)
         forecasting_series.loc[slice_s] = y_pred
+
+        confusion_matrix = confusion_matrix(y_test > 0, y_pred > 0)
+        rmse = mean_squared_error(y_test, y_pred)
+        accuracy = accuracy_score(y_test > 0, y_pred > 0)
+
         if display:
-            print('rmse for slice ' + str(slice_s))
-            mean_squared_error(y_test, y_pred)
+            print('rmse for slice ' + str(slice_s) +' : '+str(rmse))
+            print('accuracy')
+            print(accuracy)
+            print('confusion matrix')
+            print(confusion_matrix)
+
     return forecasting_series
 
